@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.1-6
+# Application Name - Health Check V0.5.2-0
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -217,7 +217,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.1-6 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.2-0 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -275,8 +275,13 @@ class Ui_MainWindow(object):
          # Set the GPS tabel text       
         #self.lbl_Alt_Info.setText(var_g_ALT)
         self.listWidget2.addItem("GPS Position \t\t" + var_g_GPS.strip())
-        
-        
+
+        al = '/sbin/ifconfig | grep inet | grep -v 127.0.0.1 | awk \'{split($2,a,":");print a[2]}\''
+        l = None
+        l = os.popen(al).read()
+        self.listWidget2.addItem("Internal IP \t\t" + l.strip())
+
+
         
 
     def reboot_sys(self):
@@ -390,6 +395,23 @@ class Ui_MainWindow(object):
         
         self.listWidget.addItem("System locale \t\t" + gc.strip())
 
+        gd = os.popen('cat /var/lib/dsme/boot_count').read()
+        gd = gd.strip()        
+        self.listWidget.addItem("Boot Count \t\t\t" + gd.strip())
+
+        ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
+        ge = ge.strip()
+        
+        self.listWidget.addItem("FM Trans Strength \t\t" + ge.strip())
+        
+        
+
+    def updateUptime(self):
+        # This one reads fremantle version number (Firmware)
+        ge = os.popen('uptime|cut -d" " -f4-|cut -d"," -f-1').read()
+        self.listWidget.addItem("System Uptime \t\t" + ge.strip())
+     
+
 # Funtion - update battery information
     def updateBatt(self):
         # This one pulls out the battery percentage
@@ -523,6 +545,7 @@ class Ui_MainWindow(object):
         self.pushButton_hw.setText(".....")
         Thread(target=self.updateMaemoV()).start()
         self.pushButton_hw.setText("......")
+        Thread(target=self.updateUptime()).start()
         self.pushButton_hw.setText(".......")
         Thread(target=self.updateBatt()).start()
         self.pushButton_hw.setText("........")
@@ -557,7 +580,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-6", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.2-0", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
